==> v6.1.4.tar.gz: thinkadmin/plugin.md <==
## ThinkAdmin 插件生态

》》》更多插件正在开发，敬请期待……《《《

目前插件更新比较频繁，如果有发现 bug，请尝试升级最新版本。

如果问题依旧，请到 [Gitee](https://gitee.com/zoujingli/ThinkAdmin/issues) 提交问题，提交的内容中需要标注插件名称及问题详情，最好附加环境版本信息。

使用插件前请务必认真阅读每个插件的介绍。

**目前已有的插件如下：**

> 后台基础 Admin 管理插件（ 已稳定可用 ）
> * 插件标识：`admin`
> * 插件包名：`zoujingli/think-plugs-admin`
> * 安装方式：`composer require zoujingli/think-plugs-admin`
> * 插件仓库：https://github.com/zoujingli/think-plugs-admin
> * 开源协议：MIT ( 免费开放 )

> 后台基础 WeChat 微信插件（ 已稳定可用 ）
> * 插件标识：`wechat`
> * 插件包名：`zoujingli/think-plugs-wechat`
> * 安装方式：`composer require zoujingli/think-plugs-wechat`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat
> * 开源协议：MIT ( 免费开放 )

> 后台静态资源初始化插件（通常不需要独立安装）
> * 插件标识：`static`
> * 插件包名：`zoujingli/think-plugs-static`
> * 安装方式：`composer require zoujingli/think-plugs-static`
> * 插件仓库：https://github.com/zoujingli/think-plugs-static
> * 开源协议：MIT ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基于 Workerman 的 Http 服务插件（ 已稳定可用 ）
> * 插件标识：`plugin-worker`
> * 插件包名：`zoujingli/think-plugs-worker`
> * 安装方式：`composer require zoujingli/think-plugs-worker`
> * 插件仓库：https://github.com/zoujingli/think-plugs-worker
> * 开源协议：Apache2 ( 免费开放 )

> 基础在线插件市场 ( 开发中，后期开放 ThinkAdmin 生态市场 )
> * 插件标识：`plugin-center`
> * 插件包名：`zoujingli/think-plugs-center`
> * 安装方式：`composer require zoujingli/think-plugs-center`
> * 插件仓库：https://github.com/zoujingli/think-plugs-center
> * 开源协议：Apache2 ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 微信开放平台基础插件（ 已稳定可用 ）
> * 插件标识：`plugin-wechat-service`
> * 插件包名：`zoujingli/think-plugin-wechat-service`
> * 安装方式：`composer require zoujingli/think-plugin-wechat-service`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat-service
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 基础用户账号管理 ( 开发中，已支持微信公众号和小程序登录，后期会增加更多 )
> * 插件标识：`plugin-account`
> * 插件包名：`zoujingli/think-plugs-account`
> * 安装方式：`composer require zoujingli/think-plugs-account`
> * 插件仓库：https://github.com/zoujingli/think-plugs-account
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 基础支付配置管理 ( 开发中，还未发布 )
> * 插件标识：`plugin-payment`
> * 插件包名：`zoujingli/think-plugs-payment`
> * 安装方式：`composer require zoujingli/think-plugs-payment`
> * 插件仓库：https://github.com/zoujingli/think-plugs-payment
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 基础商品管理插件（目前处于重构中，基于 gitee 发布不太稳定，感觉不太实用）
> * 插件标识：`plugin-base-goods`
> * 插件包名：`zoujingli/think-plugs-base-goods`
> * 安装方式：`composer require zoujingli/think-plugs-base-goods dev-master`
> * 插件仓库：https://gitee.com/zoujingli/think-plugs-base-goods
> * 开源协议：MIT ( 免费开放 )

==> v6.1.5.tar.gz: thinkadmin/plugin.md <==
## ThinkAdmin 插件生态

》》》更多插件正在开发，敬请期待……《《《

目前插件更新比较频繁，如果有发现 **BUG**，请尝试升级最新版本。

如果问题依旧，请到 [Gitee](https://gitee.com/zoujingli/ThinkAdmin/issues) 提交问题，提交的内容中需要标注插件名称及问题详情，最好附加环境版本信息。

使用插件前请务必认真阅读每个插件的介绍。

**目前已有的插件如下：**

> 后台基础 Admin 管理插件（ 已稳定可用 ）
> * 插件标识：`admin`
> * 插件包名：`zoujingli/think-plugs-admin`
> * 安装方式：`composer require zoujingli/think-plugs-admin`
> * 插件仓库：https://github.com/zoujingli/think-plugs-admin
> * 开源协议：MIT ( 免费开放 )

> 后台基础 WeChat 微信插件（ 已稳定可用 ）
> * 插件标识：`wechat`
> * 插件包名：`zoujingli/think-plugs-wechat`
> * 安装方式：`composer require zoujingli/think-plugs-wechat`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat
> * 开源协议：MIT ( 免费开放 )

> 后台静态资源初始化插件（通常不需要独立安装）
> * 插件标识：`static`
> * 插件包名：`zoujingli/think-plugs-static`
> * 安装方式：`composer require zoujingli/think-plugs-static`
> * 插件仓库：https://github.com/zoujingli/think-plugs-static
> * 开源协议：MIT ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 基于 Workerman 的 Http 服务插件（ 已稳定可用 ）
> * 插件标识：`plugin-worker`
> * 插件包名：`zoujingli/think-plugs-worker`
> * 安装方式：`composer require zoujingli/think-plugs-worker`
> * 插件仓库：https://github.com/zoujingli/think-plugs-worker
> * 开源协议：Apache2 ( 免费开放 )

> 基础在线插件市场 ( 开发中，后期开放 ThinkAdmin 生态市场 )
> * 插件标识：`plugin-center`
> * 插件包名：`zoujingli/think-plugs-center`
> * 安装方式：`composer require zoujingli/think-plugs-center`
> * 插件仓库：https://github.com/zoujingli/think-plugs-center
> * 开源协议：Apache2 ( 免费开放，里面有部分其他开源协议，具体可以查看源文件 )

> 微信开放平台基础插件（ 已稳定可用 ）
> * 插件标识：`plugin-wechat-service`
> * 插件包名：`zoujingli/think-plugs-wechat-service`
> * 安装方式：`composer require zoujingli/think-plugs-wechat-service`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wechat-service
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 多端账号管理 ( 测试中，可升级 )
> * 插件标识：`plugin-account`
> * 插件包名：`zoujingli/think-plugs-account`
> * 安装方式：`composer require zoujingli/think-plugs-account`
> * 插件仓库：https://github.com/zoujingli/think-plugs-account
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 多端支付管理 ( 开发中，还未发布 )
> * 插件标识：`plugin-payment`
> * 插件包名：`zoujingli/think-plugs-payment`
> * 安装方式：`composer require zoujingli/think-plugs-payment`
> * 插件仓库：https://github.com/zoujingli/think-plugs-payment
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 多端微商城系统 ( 开发中，还未发布 )
> * 插件标识：`plugin-wemall`
> * 插件包名：`zoujingli/think-plugs-wemall`
> * 安装方式：`composer require zoujingli/think-plugs-wemall`
> * 插件仓库：https://github.com/zoujingli/think-plugs-wemall
> * 授权协议：VIP授权 ( 非VIP用户仅可用于学习，不得商用 )

> 基础商品管理插件（目前处于重构中，基于 Gitee 发布不太稳定，感觉不太实用）
> * 插件标识：`plugin-base-goods`
> * 插件包名：`zoujingli/think-plugs-base-goods`
> * 安装方式：`composer require zoujingli/think-plugs-base-goods dev-master`
> * 插件仓库：https://gitee.com/zoujingli/think-plugs-base-goods
> * 开源协议：MIT ( 免费开放，不建议使用 )
